/*
 * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
 *
 * Solarus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Solarus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef SOLARUS_STARTING_LOCATION_MODE_H
#define SOLARUS_STARTING_LOCATION_MODE_H

#include "solarus/core/Common.h"
#include "solarus/core/EnumInfo.h"

namespace Solarus {

/**
 * \brief Whether a destination updates the starting location when using it.
 */
enum class StartingLocationMode {

  WHEN_WORLD_CHANGES,        /**< Update if the current world has just changed. */
  YES,                       /**< Update the starting location. */
  NO                         /**< Don't update the starting location. */
};

template <>
struct SOLARUS_API EnumInfoTraits<StartingLocationMode> {
  static const std::string pretty_name;

  static const EnumInfo<StartingLocationMode>::names_type names;
};

}

#endif

